/*
 * Ambient - the ultimate desktop
 * ------------------------------
 * Copyright 2001-2005 by David Gerber <zapek@morphos.net>
 * Copyright 2005-2006 Ambient Open Source Team
 * All Rights Reserved
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * $Id: makedir.c,v 1.8 2008/07/24 13:07:02 fab Exp $
 */

#include "ambient.h"

/* public */
#include <proto/dos.h>

/* private */
#include "deficon_getpath.h"
#include "makedir.h"
#include "fastcopy.h"
#include "name.h"
#include "mui_func.h"
#include "notify.h"
#include "smartreq.h"
#include "methodstack.h"


ULONG tr_makedir(CONST_STRPTR path, ULONG createicon)
{
	BPTR l;

	THREAD;

	methodstack_push_sync( app, 3, MM_Application_EnableDOSNotify, path, FALSE );

	restart_makedir:

	if ((l = CreateDir(path)))
	{
		STRPTR icon;

		UnLock(l);

		notify_action(path, NOTIFYTAG_Monitor_File, NOTIFYTAG_Monitor_File_Create);

		if (createicon)
		{
			if ((icon = name_build_info(path)))
			{
				TEXT buf[PATH_SIZE];

				if (deficon_getpath(buf, PATH_SIZE, "def_drawer.info"))
				{
					ULONG reqflags = 0;

					if (fastcopy(NULL, buf, icon, 512, FALSE, NULL, NULL, 1, NULL, &reqflags) == FASTCOPY_OK) /* XXX: this sucks, but it shuts up Henes & Frodon */
					{
						notify_action(icon, NOTIFYTAG_Monitor_File, NOTIFYTAG_Monitor_File_Create);
					}
					/* XXX */
				}
				name_delete(icon);
			}
		}
	}
	else
	{
		if (smartreq_request_sync(NULL, "Ambient  Makedir", "*_Retry|Cancel", MV_Notification_Error, "Couldn't create directory '%s'.\nDOS error: %S (#%N).", path) == 1)
		{
			goto restart_makedir;
		}
	}

	methodstack_push_sync( app, 3, MM_Application_EnableDOSNotify, path, TRUE );

	return (TRUE); /* XXX: in fact we never report failure.. but we should */
}
